==> haskell-code-page-0.1.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: code-page
version: 0.1.3
id: code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V
key: code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V
license: BSD-3-Clause
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Ryan Scott
stability: Provisional
homepage: https://github.com/RyanGlScott/code-page
synopsis: Windows code page library for Haskell
description:
    This library provides two modules:
    .
    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.
    .
    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.
category: System
abi: ac79c284619ed805973e8a29b0490575
exposed: True
exposed-modules:
    System.IO.CodePage System.Win32.CodePage
import-dirs: /usr/lib/ghc-8.4.3/site-local/code-page-0.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/code-page-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/code-page-0.1.3
hs-libraries: HScode-page-0.1.3-78bf3rlibAi1l7KbTfbq3V
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html: /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-code-page-0.1.3-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: code-page
version: 0.1.3
id: code-page-0.1.3-Kc5hEpEY5ob2rh8HXOjZRD
key: code-page-0.1.3-Kc5hEpEY5ob2rh8HXOjZRD
license: BSD-3-Clause
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Ryan Scott
stability: Provisional
homepage: https://github.com/RyanGlScott/code-page
synopsis: Windows code page library for Haskell
description:
    This library provides two modules:
    .
    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.
    .
    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.
category: System
abi: e6f2506f2d0a8a95ff8e0168b9f52c8d
exposed: True
exposed-modules:
    System.IO.CodePage System.Win32.CodePage
import-dirs: /usr/lib/ghc-8.6.1/site-local/code-page-0.1.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/code-page-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/code-page-0.1.3
hs-libraries: HScode-page-0.1.3-Kc5hEpEY5ob2rh8HXOjZRD
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html: /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
